pub enum TaskBackgroundStatus {
Queued,
Blocked,
AwaitingApproval,
Running,
Succeeded,
Failed,
Cancelled,
}Expand description
Background execution status for tasks that represent long-running work.
This is primarily intended for UI dashboards to reflect delegated work (e.g. orchestrator / agent tasks) that may run asynchronously.
Variants
Queued
The background job has been queued but has not started.
Blocked
The background job is blocked on another dependency or review gate.
AwaitingApproval
The background job is waiting on explicit approval.
Running
The background job is currently running.
Succeeded
The background job completed successfully.
Failed
The background job failed.
Cancelled
The background job was cancelled.