pub enum TrackedTaskFinalization {
Completed,
StillInProgress {
open_subtask_ids: Vec<String>,
},
}Expand description
Result of reconciling a tracked task after an agent turn.
Variants
Completed
The tracked task and its subtree are complete.
StillInProgress
The tracked task still has open subtasks and should remain in progress.